@@ -10,9 +10,7 @@
  * $Id: hig.c 13677 2012-12-16 22:51:29Z jordan $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtk.h>
 #include "hig.h"
@@ -29,16 +27,6 @@ hig_workarea_create (void)
     return grid;
 }
 
-void
-hig_workarea_add_section_divider (GtkWidget * t, guint * row)
-{
-    GtkWidget * w = gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
-
-    gtk_widget_set_size_request (w, 0u, 6u);
-    gtk_grid_attach (GTK_GRID (t), w, 0, *row, 2, 1);
-    ++ * row;
-}
-
 void
 hig_workarea_add_section_title_widget (GtkWidget * t, guint * row, GtkWidget * w)
 {
@@ -55,7 +43,8 @@ hig_workarea_add_section_title (GtkWidget *  t, guint * row, const char * sectio
 
     g_snprintf (buf, sizeof (buf), "<b>%s</b>", section_title);
     l = gtk_label_new (buf);
-    gtk_misc_set_alignment (GTK_MISC (l), 0.0f, 0.5f);
+    gtk_label_set_xalign (GTK_LABEL (l), 0.0f);
+    gtk_label_set_yalign (GTK_LABEL (l), 0.5f);
     gtk_label_set_use_markup (GTK_LABEL (l), TRUE);
     hig_workarea_add_section_title_widget (t, row, l);
 }
@@ -64,7 +53,7 @@ void
 hig_workarea_add_wide_control (GtkWidget * t, guint * row, GtkWidget * w)
 {
     gtk_widget_set_hexpand (w, TRUE);
-    gtk_widget_set_margin_left (w, 18);
+    gtk_widget_set_margin_start (w, 18);
     gtk_grid_attach (GTK_GRID (t), w, 0, *row, 2, 1);
     ++ * row;
 }
@@ -92,20 +81,23 @@ hig_workarea_add_wide_checkbutton (GtkWidget  * t,
 void
 hig_workarea_add_label_w (GtkWidget * t, guint row, GtkWidget * w)
 {
-    gtk_widget_set_margin_left (w, 18);
-    if (GTK_IS_MISC (w))
-        gtk_misc_set_alignment (GTK_MISC (w), 0.0f, 0.5f);
-    if (GTK_IS_LABEL (w))
+    gtk_widget_set_margin_start (w, 18);
+    if (GTK_IS_LABEL (w)) {
         gtk_label_set_use_markup (GTK_LABEL (w), TRUE);
+        gtk_label_set_xalign(GTK_LABEL (w), 0.0f);
+        gtk_label_set_yalign(GTK_LABEL (w), 0.5f);
+    }
     gtk_grid_attach (GTK_GRID (t), w, 0, row, 1, 1);
 }
 
 static void
 hig_workarea_add_tall_control (GtkWidget * t, guint row, GtkWidget * control)
 {
-    if (GTK_IS_MISC (control))
-        gtk_misc_set_alignment (GTK_MISC (control), 0.0f, 0.5f);
+    if (GTK_IS_LABEL (control)) {
 
+        gtk_label_set_xalign (GTK_LABEL (control), 0.0f);
+        gtk_label_set_yalign (GTK_LABEL (control), 0.5f);
+    }
     g_object_set (control, "expand", TRUE, NULL);
     gtk_grid_attach (GTK_GRID (t), control, 1, row, 1, 1);
 }
@@ -113,9 +105,10 @@ hig_workarea_add_tall_control (GtkWidget * t, guint row, GtkWidget * control)
 static void
 hig_workarea_add_control (GtkWidget * t, guint row, GtkWidget * control)
 {
-    if (GTK_IS_MISC (control))
-        gtk_misc_set_alignment (GTK_MISC (control), 0.0f, 0.5f);
-
+    if (GTK_IS_LABEL (control)) {
+        gtk_label_set_xalign (GTK_LABEL (control), 0.0f);
+        gtk_label_set_yalign (GTK_LABEL (control), 0.5f);
+    }
     gtk_widget_set_hexpand (control, TRUE);
     gtk_grid_attach (GTK_GRID (t), control, 1, row, 1, 1);
 }
