@@ -6,9 +6,7 @@
  * $Id: icons.c 12639 2011-08-07 18:41:13Z jordan $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>             /* strcmp */
 #include <glib.h>
@@ -53,12 +51,11 @@ static GdkPixbuf *create_void_pixbuf(int width, int height)
 }
 
 
-static int get_size_in_pixels(GtkWidget * widget, GtkIconSize icon_size)
+static int get_size_in_pixels(GtkIconSize icon_size)
 {
     int width, height;
 
-    gtk_icon_size_lookup_for_settings(gtk_widget_get_settings(widget),
-                                      icon_size, &width, &height);
+    gtk_icon_size_lookup(icon_size, &width, &height);
     return MAX(width, height);
 }
 
@@ -72,7 +69,7 @@ static IconCache *icon_cache_new(GtkWidget * for_widget, int icon_size)
     icon_cache = g_new0(IconCache, 1);
     icon_cache->icon_theme =
         gtk_icon_theme_get_for_screen(gtk_widget_get_screen(for_widget));
-    icon_cache->icon_size = get_size_in_pixels(for_widget, icon_size);
+    icon_cache->icon_size = get_size_in_pixels(icon_size);
     icon_cache->cache =
         g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
                               g_object_unref);
@@ -142,7 +139,7 @@ static GdkPixbuf *get_themed_icon_pixbuf(GThemedIcon * icon,
         g_clear_error(&error);
     }
 
-    gtk_icon_info_free(icon_info);
+    g_clear_object(&icon_info);
     g_strfreev(icon_names);
 
     return pixbuf;
