@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdint.h>
 #include <gtk/gtk.h>
@@ -72,9 +70,9 @@ trg_cell_renderer_file_icon_refresh(TrgCellRendererFileIcon * fi)
     if (priv->file_id == -2) {
         return;
     } else if (priv->file_id == -1) {
-        g_object_set(fi, "stock-id", GTK_STOCK_DIRECTORY, NULL);
+        g_object_set(fi, "icon-name", "folder", NULL);
     } else if (priv->text) {
-#ifndef WIN32
+#ifndef G_OS_WIN32
         gboolean uncertain;
         gchar *mimetype =
             g_content_type_guess(priv->text, NULL, 0, &uncertain);
@@ -89,10 +87,10 @@ trg_cell_renderer_file_icon_refresh(TrgCellRendererFileIcon * fi)
             g_object_set(fi, "gicon", icon, NULL);
             g_object_unref(icon);
         } else {
-            g_object_set(fi, "stock-id", GTK_STOCK_FILE, NULL);
+            g_object_set(fi, "icon-name", "file", NULL);
         }
 #else
-        g_object_set(fi, "stock-id", GTK_STOCK_FILE, NULL);
+        g_object_set(fi, "icon-name", "file", NULL);
 #endif
     }
 }
