@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -82,7 +80,7 @@ trg_model_remove_removed(GtkListStore * model, gint serial_column,
 struct find_existing_item_foreach_args {
     gint64 id;
     gint search_column;
-    GtkTreeIter *iter;
+    GtkTreeIter iter;
     gboolean found;
 };
 
@@ -97,7 +95,7 @@ find_existing_item_foreachfunc(GtkTreeModel * model,
 
     gtk_tree_model_get(model, iter, args->search_column, &currentId, -1);
     if (currentId == args->id) {
-        args->iter = iter;
+        args->iter = *iter;
         return args->found = TRUE;
     }
 
@@ -114,6 +112,6 @@ find_existing_model_item(GtkTreeModel * model, gint search_column,
     args.search_column = search_column;
     gtk_tree_model_foreach(model, find_existing_item_foreachfunc, &args);
     if (args.found == TRUE)
-        *iter = *(args.iter);
+        *iter = args.iter;
     return args.found;
 }
