@@ -17,6 +17,9 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
+
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include "trg-prefs.h"
@@ -30,7 +33,7 @@
  */
 
 G_DEFINE_TYPE(TrgPersistentTreeView, trg_persistent_tree_view,
-              GTK_TYPE_VBOX)
+              GTK_TYPE_BOX)
 #define GET_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRG_TYPE_PERSISTENT_TREE_VIEW, TrgPersistentTreeViewPrivate))
 typedef struct _TrgPersistentTreeViewPrivate
@@ -383,24 +386,24 @@ static GObject *trg_persistent_tree_view_constructor(GType type,
 
     hbox = trg_hbox_new(FALSE, 0);
 
-    w = gtk_button_new_from_stock(GTK_STOCK_ADD);
+    w = gtk_button_new_with_label(_("Add"));
     g_signal_connect(w, "clicked",
                      G_CALLBACK(trg_persistent_tree_view_add_cb), object);
     gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
 
-    w = priv->delButton = gtk_button_new_from_stock(GTK_STOCK_DELETE);
+    w = priv->delButton = gtk_button_new_with_label(_("Delete"));
     gtk_widget_set_sensitive(w, FALSE);
     g_signal_connect(w, "clicked",
                      G_CALLBACK(trg_persistent_tree_view_del_cb), object);
     gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
 
-    w = priv->upButton = gtk_button_new_from_stock(GTK_STOCK_GO_UP);
+    w = priv->upButton = gtk_button_new_with_label(_("Up"));
     gtk_widget_set_sensitive(w, FALSE);
     g_signal_connect(w, "clicked",
                      G_CALLBACK(trg_persistent_tree_view_up_cb), object);
     gtk_box_pack_start(GTK_BOX(hbox), w, FALSE, FALSE, 4);
 
-    w = priv->downButton = gtk_button_new_from_stock(GTK_STOCK_GO_DOWN);
+    w = priv->downButton = gtk_button_new_with_label(_("Down"));
     gtk_widget_set_sensitive(w, FALSE);
     g_signal_connect(w, "clicked",
                      G_CALLBACK(trg_persistent_tree_view_down_cb), object);
@@ -507,6 +510,7 @@ TrgPersistentTreeView *trg_persistent_tree_view_new(TrgPrefs * prefs,
         g_object_new(TRG_TYPE_PERSISTENT_TREE_VIEW, "prefs", prefs,
                      "conf-key", key, "persistent-model",
                      model, "conf-flags", conf_flags,
+                     "orientation", GTK_ORIENTATION_VERTICAL,
                      NULL);
 
     return TRG_PERSISTENT_TREE_VIEW(obj);
