@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -297,7 +295,7 @@ static GObject *trg_stats_dialog_constructor(GType type,
     gtk_window_set_transient_for(GTK_WINDOW(obj),
                                  GTK_WINDOW(priv->parent));
     gtk_window_set_destroy_with_parent(GTK_WINDOW(obj), TRUE);
-    gtk_dialog_add_button(GTK_DIALOG(obj), GTK_STOCK_CLOSE,
+    gtk_dialog_add_button(GTK_DIALOG(obj), _("_Close"),
                           GTK_RESPONSE_CLOSE);
 
     gtk_container_set_border_width(GTK_CONTAINER(obj), GUI_PAD);
