@@ -17,9 +17,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -191,9 +189,8 @@ static void trg_torrent_model_ref_free(gpointer data)
         GtkTreeIter iter;
         JsonObject *json;
         if (gtk_tree_model_get_iter(model, &iter, path)) {
-            gtk_tree_model_get(model, &iter, TORRENT_COLUMN_JSON, &json,
-                               -1);
-            json_object_unref(json);
+            gtk_tree_model_get(model, &iter, TORRENT_COLUMN_JSON, &json, -1);
+            g_clear_pointer(&json, json_object_unref);
             g_object_set_data(G_OBJECT(model), PROP_REMOVE_IN_PROGRESS,
                               GINT_TO_POINTER(TRUE));
             gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
@@ -344,7 +341,7 @@ trg_torrent_model_stats_scan_foreachfunc(GtkTreeModel *
     else
         stats->incomplete++;
 
-    if (flags & TORRENT_FLAG_CHECKING)
+    if (flags & TORRENT_FLAG_CHECKING_ANY)
         stats->checking++;
 
     if (flags & TORRENT_FLAG_ACTIVE)
@@ -407,7 +404,7 @@ gchar *shorten_download_dir(TrgClient * tc, const gchar * downloadDir)
             return g_strdup(_("Default"));
 
         if (g_str_has_prefix(downloadDir, defaultDownloadDir)) {
-            int offset = strlen(defaultDownloadDir);
+            size_t offset = strlen(defaultDownloadDir);
             if (*(downloadDir + offset) == '/')
                 offset++;
 
@@ -419,7 +416,7 @@ gchar *shorten_download_dir(TrgClient * tc, const gchar * downloadDir)
     return g_strdup(downloadDir);
 }
 
-static inline void
+static void
 update_torrent_iter(TrgTorrentModel * model,
                     TrgClient * tc, gint64 rpcv,
                     gint64 serial, GtkTreeIter * iter,
@@ -631,8 +628,7 @@ update_torrent_iter(TrgTorrentModel * model,
         *whatsChanged |= TORRENT_UPDATE_PATH_CHANGE;
     }
 
-    if (lastJson)
-        json_object_unref(lastJson);
+    g_clear_pointer(&lastJson, json_object_unref);
 
     if ((lastFlags & TORRENT_FLAG_DOWNLOADING)
         && (!(newFlags & TORRENT_FLAG_DOWNLOADING))
@@ -644,11 +640,9 @@ update_torrent_iter(TrgTorrentModel * model,
 
     trg_torrent_model_count_peers(model, iter, t);
 
-    if (firstTrackerHost)
-        g_free(firstTrackerHost);
+    g_free(firstTrackerHost);
 
-    if (peerSources)
-        g_free(peerSources);
+    g_free(peerSources);
 
     g_free(lastDownloadDir);
     g_free(statusString);
